@@ -6,11 +6,11 @@ PDL::Basic -- Basic utility functions for PDL
 =head1 DESCRIPTION
 
 This module contains basic utility functions for
-creating and manipulating piddles. Most of these functions
+creating and manipulating ndarrays. Most of these functions
 are simplified interfaces to the more flexible functions in
-the modules 
-L<PDL::Primitive> 
-and 
+the modules
+L<PDL::Primitive>
+and
 L<PDL::Slices>.
 
 =head1 SYNOPSIS
@@ -50,12 +50,12 @@ use PDL::Options;
 
 =for ref
 
-Fills a piddle with X index values.  Uses similar specifications to
+Fills an ndarray with X index values.  Uses similar specifications to
 L</zeroes> and L</new_from_specification>.
 
-CAVEAT: 
+CAVEAT:
 
-If you use the single argument piddle form (top row
+If you use the single argument ndarray form (top row
 in the usage table) the output will have the same type as the input;
 this may give surprising results if, e.g., you have a byte array with
 a dimension of size greater than 256.  To force a type, use the third form.
@@ -88,7 +88,7 @@ etc. see L<zeroes|PDL::Core/zeroes>.
 
 =for ref
 
-Fills a piddle with Y index values.  See the CAVEAT for L</xvals>.
+Fills an ndarray with Y index values.  See the CAVEAT for L</xvals>.
 
 =for usage
 
@@ -117,7 +117,7 @@ etc. see L<zeroes|PDL::Core/zeroes>.
 
 =for ref
 
-Fills a piddle with Z index values.  See the CAVEAT for L</xvals>.
+Fills an ndarray with Z index values.  See the CAVEAT for L</xvals>.
 
 =for usage
 
@@ -157,9 +157,9 @@ X axis values between endpoints (see L</xvals>).
  $y = $w->ylinvals(-2,-1);
  # calculate Z for X between 0.5 and 1.5 and
  # Y between -2 and -1.
- $z = f($x,$y);            
+ $z = f($x,$y);
 
-C<xlinvals>, C<ylinvals> and C<zlinvals> return a piddle with the same shape
+C<xlinvals>, C<ylinvals> and C<zlinvals> return an ndarray with the same shape
 as their first argument and linearly scaled values between the two other
 arguments along the given axis.
 
@@ -192,9 +192,9 @@ X axis values logarithmically spaced between endpoints (see L</xvals>).
  $y = $w->ylinvals(1e-4,1e3);
  # calculate Z for X between 1e-6 and 1e-3 and
  # Y between 1e-4 and 1e3.
- $z = f($x,$y);            
+ $z = f($x,$y);
 
-C<xlogvals>, C<ylogvals> and C<zlogvals> return a piddle with the same shape
+C<xlogvals>, C<ylogvals> and C<zlogvals> return an ndarray with the same shape
 as their first argument and logarithmically scaled values between the two other
 arguments along the given axis.
 
@@ -316,19 +316,19 @@ $indices = allaxisvals($type,@dimlist);
 
 =for ref
 
-Enumerate pixel coordinates for an N-D piddle
+Enumerate pixel coordinates for an N-D ndarray
 
 Returns an enumerated list of coordinates suitable for use in
 L<indexND|PDL::Slices/indexND> or L<range|PDL::Slices/range>: you feed
-in a dimension list and get out a piddle whose 0th dimension runs over
+in a dimension list and get out an ndarray whose 0th dimension runs over
 dimension index and whose 1st through Nth dimensions are the
-dimensions given in the input.  If you feed in a piddle instead of a
+dimensions given in the input.  If you feed in an ndarray instead of a
 perl list, then the dimension list is used, as in L</xvals> etc.
 
-Unlike L</xvals> etc., if you supply a piddle input, you get 
-out a piddle of the default piddle type: double.   This causes less
+Unlike L</xvals> etc., if you supply an ndarray input, you get
+out an ndarray of the default ndarray type: double.   This causes less
 surprises than the previous default of keeping the data type of
-the input piddle since that rarely made sense in most usages.
+the input ndarray since that rarely made sense in most usages.
 
 =for usage
 
@@ -355,9 +355,9 @@ $indices = ndcoords($type,@dimlist);
    ]
   ]
 
-  pdl> $w = zeroes(byte,2,3);        # $w is a 2x3 byte piddle
+  pdl> $w = zeroes(byte,2,3);        # $w is a 2x3 byte ndarray
   pdl> $y = ndcoords($w);            # $y inherits $w's type
-  pdl> $c = ndcoords(long,$w->dims); # $c is a long piddle, same dims as $y
+  pdl> $c = ndcoords(long,$w->dims); # $c is a long ndarray, same dims as $y
   pdl> help $y;
   This variable is   Byte D [2,2,3]              P            0.01Kb
   pdl> help $c;
@@ -366,19 +366,19 @@ $indices = ndcoords($type,@dimlist);
 
 =cut
 
-sub PDL::ndcoords { 
+sub PDL::ndcoords {
   my $type;
   if(ref $_[0] eq 'PDL::Type') {
     $type = shift;
   }
-  
+
   my @dims = (ref $_[0]) ? (shift)->dims : @_;
   my @d = @dims;
   unshift(@d,scalar(@dims));
   unshift(@d,$type) if defined($type);
 
   $out = PDL->zeroes(@d);
-  
+
   for my $d(0..$#dims) {
     my $w = $out->index($d)->mv($d,0);
     $w .= xvals($w);
@@ -389,13 +389,12 @@ sub PDL::ndcoords {
 *ndcoords = \&PDL::ndcoords;
 *allaxisvals = \&PDL::ndcoords;
 *PDL::allaxisvals = \&PDL::ndcoords;
- 
 
 =head2 hist
 
 =for ref
 
-Create histogram of a piddle
+Create histogram of an ndarray
 
 =for usage
 
@@ -410,7 +409,7 @@ or
 If C<hist> is run in list context, C<$xvals> gives the
 computed bin centres as double values.
 
-A nice idiom (with 
+A nice idiom (with
 L<PDL::Graphics::PGPLOT>) is
 
  bin hist $data;  # Plot histogram
@@ -436,7 +435,7 @@ sub PDL::hist {
     my($pdl,$min,$max,$step)=@_;
     my $xvals;
 
-    ($step, $min, $bins, $xvals) = 
+    ($step, $min, $bins, $xvals) =
         _hist_bin_calc($pdl, $min, $max, $step, wantarray());
 
     PDL::Primitive::histogram($pdl->clump(-1),(my $hist = null),
@@ -449,7 +448,7 @@ sub PDL::hist {
 
 =for ref
 
-Create a weighted histogram of a piddle
+Create a weighted histogram of an ndarray
 
 =for usage
 
@@ -460,7 +459,7 @@ If requested, C<$xvals> gives the computed bin centres
 as type double values.  C<$data> and C<$wt> should have
 the same dimensionality and extents.
 
-A nice idiom (with 
+A nice idiom (with
 L<PDL::Graphics::PGPLOT>) is
 
  bin whist $data, $wt;  # Plot histogram
@@ -471,7 +470,7 @@ L<PDL::Graphics::PGPLOT>) is
  [13 10 13 10 9 13 9 12 11 10 10 13 7 6 8 10 11 7 12 9 11 11 12 6 12 7]
  pdl> $wt = grandom($y->nelem)
  pdl> $h = whist $y, $wt, 0, 20, 1 # hist with step 1, min 0 and 20 bins
- pdl> p $h                        
+ pdl> p $h
  [0 0 0 0 0 0 -0.49552342  1.7987439 0.39450696  4.0073722 -2.6255299 -2.5084501  2.6458365  4.1671676 0 0 0 0 0 0]
 
 
@@ -483,7 +482,7 @@ sub PDL::whist {
     my($pdl,$wt,$min,$max,$step)=@_;
     my $xvals;
 
-    ($step, $min, $bins, $xvals) = 
+    ($step, $min, $bins, $xvals) =
         _hist_bin_calc($pdl, $min, $max, $step, wantarray());
 
     PDL::Primitive::whistogram($pdl->clump(-1),$wt->clump(-1),
@@ -496,7 +495,7 @@ sub _hist_bin_calc {
     $min = $pdl->min() unless defined $min;
     $max = $pdl->max() unless defined $max;
     my $nelem = $pdl->nelem;
-    barf "empty piddle, no values to work with" if $nelem == 0;
+    barf "empty ndarray, no values to work with" if $nelem == 0;
 
     $step = ($max-$min)/(($nelem>10_000) ? 100 : sqrt($nelem)) unless defined $step;
     barf "step is zero (or all data equal to one value)" if $step == 0;
@@ -550,11 +549,11 @@ sub PDL::sequence {
 
 =for ref
 
-Fills a piddle with radial distance values from some centre.
+Fills an ndarray with radial distance values from some centre.
 
 =for usage
 
- $r = rvals $piddle,{OPTIONS};
+ $r = rvals $ndarray,{OPTIONS};
  $r = rvals [OPTIONAL TYPE],$nx,$ny,...{OPTIONS};
 
 =for options
@@ -607,7 +606,7 @@ so now
  distance($w, $centre, \&euclid);
 
 will emulate rvals, while C<\&l1> and C<\&linfty> will generate other
-well-known norms. 
+well-known norms.
 
 =cut
 
@@ -615,7 +614,7 @@ sub rvals { ref($_[0]) && ref($_[0]) ne 'PDL::Type' ? $_[0]->rvals(@_[1..$#_]) :
 sub PDL::rvals { # Return radial distance from given point and offset
     my $class = shift;
     my $opt = pop @_ if ref($_[$#_]) eq "HASH";
-    my %opt = defined $opt ? 
+    my %opt = defined $opt ?
                iparse( {
 			CENTRE  => undef, # needed, otherwise centre/center handling painful
 			Squared => 0,
@@ -643,18 +642,18 @@ sub PDL::rvals { # Return radial distance from given point and offset
 
 =for ref
 
-Fills a piddle with index values on Nth dimension
+Fills an ndarray with index values on Nth dimension
 
 =for usage
 
- $z = axisvals ($piddle, $nth);
+ $z = axisvals ($ndarray, $nth);
 
 This is the routine, for which L</xvals>, L</yvals> etc
 are mere shorthands. C<axisvals> can be used to fill along any dimension,
 using a parameter.
 
-See also L</allaxisvals>, which generates all axis values 
-simultaneously in a form useful for L</range>, L</interpND>, 
+See also L</allaxisvals>, which generates all axis values
+simultaneously in a form useful for L</range>, L</interpND>,
 L</indexND>, etc.
 
 Note the 'from specification' style (see L<zeroes|PDL::Core/zeroes>) is
@@ -735,7 +734,7 @@ sub PDL::similar_assign {
 
 =for ref
 
-transpose rows and columns. 
+transpose rows and columns.
 
 =for usage
 
@@ -748,26 +747,21 @@ transpose rows and columns.
  [
   [0 1 2]
   [3 4 5]
- ]                                                                               
+ ]
  pdl> p transpose( $w )
  [
   [0 3]
   [1 4]
-  [2 5]                                                                          
+  [2 5]
  ]
 
 =cut
 
 sub PDL::transpose {
-	my($this) = @_;
-	if($this->getndims <= 1) {
-	    if($this->getndims==0) {
-		return pdl $this->dummy(0)->dummy(0);
-	    } else {
-		return pdl $this->dummy(0);
-	    }
-	}
-	return $this->xchg(0,1);
+  my ($this) = @_;
+  $this->getndims > 1 ? $this->xchg(0,1) :
+  $this->getndims > 0 ? $this->dummy(0) :
+  $this->dummy(0)->dummy(0);
 }
 
 1;
